@@ -807,8 +807,41 @@ text_max_length=%ld, forward=%d)",
 		break;
 
 	    case 0x14:
-		in_step = 4;
-		context->skip_code = 0x15;
+		/* beginning of color chart */
+		/* argv[1] is number of color (1-). */
+		argc = 2;
+		if(eb_uint2(cache_p + 4) == 0x1f15) {
+		    char in_buffer[2];
+		    if (eb_uint1(cache_p + 2) != 0x1e) {
+			error_code = EB_ERR_UNEXP_TEXT;
+			goto failed;
+		    }
+		    in_buffer[0] = 0;
+		    in_buffer[1] = *(cache_p + 3);
+		    in_step = 4;
+		    argv[1] = eb_bcd2(in_buffer);
+		} else if(eb_uint2(cache_p + 6) == 0x1f15) {
+		    char in_buffer[2];
+		    if (eb_uint1(cache_p + 2) != 0x1e ||
+			eb_uint1(cache_p + 4) != 0x1e) {
+			error_code = EB_ERR_UNEXP_TEXT;
+			goto failed;
+		    }
+		    in_buffer[0] = *(cache_p + 3);
+		    in_buffer[1] = *(cache_p + 5);
+		    in_step = 6;
+		    argv[1] = eb_bcd2(in_buffer);
+		} else {
+		    error_code = EB_ERR_UNEXP_TEXT;
+		    goto failed;
+		}
+		hook = hookset->hooks + EB_HOOK_BEGIN_COLOR_CHART;
+		break;
+
+	    case 0x15:
+		/* end of color chart */
+		in_step = 2;
+		hook = hookset->hooks + EB_HOOK_END_COLOR_CHART;
 		break;
 
 	    case 0x1a: case 0x1b: case 0x1e: case 0x1f:
@@ -1667,7 +1700,7 @@ eb_is_text_stopped(EB_Book *book)
 {
     int is_stopped = 0;
 
-    eb_lock(book);
+    eb_lock(&book->lock);
     LOG(("in: eb_is_text_stopped(book=%d)", (int)book->code));
 
     if (book->subbook_current != NULL) {
