@@ -1343,7 +1343,7 @@ eb_convert_utf8(EB_Book *book, const char *input_word, char *word,
     const unsigned char *tail;
     int word_length = 0;
     int count = 0, chr;
-    unsigned char *result;
+    char *result;
 
     LOG(("in: eb_convert_utf8(book=%d, input_word=%s)", (int)book->code,
 	 eb_quoted_string(input_word)));
@@ -1356,7 +1356,7 @@ eb_convert_utf8(EB_Book *book, const char *input_word, char *word,
 	    continue;
 	}
 
-	count = eb_read_utf8 (inp, &chr);
+	count = eb_read_utf8 ((const char *)inp, &chr);
 	if (!count) {
 	    error_code = EB_ERR_BAD_WORD;
 	    goto failed;
@@ -1392,7 +1392,7 @@ eb_convert_utf8(EB_Book *book, const char *input_word, char *word,
 	goto failed;
       }
 */
-      result = eb_normalize_utf8(book, chr);
+	result = eb_normalize_utf8(book, chr);
 
       if (result == NULL) {
 	if (EB_MAX_WORD_LENGTH < word_length + count) {
