@@ -526,6 +526,9 @@ eb_load_subbook_indexes(EB_Book *book)
 	case 0xd8:
 	    memcpy(&subbook->sound, &search, sizeof(EB_Search));
 	    break;
+	case 0xe0:
+	    memcpy(&subbook->color_chart, &search, sizeof(EB_Search));
+	    break;
 	case 0xf1:
 	    if (book->disc_code == EB_DISC_EB) {
 		subbook->wide_fonts[EB_FONT_16].page = search.start_page;
