@@ -329,8 +329,14 @@ ebzip_zip_file_internal(const char *out_file_name, const char *in_file_name,
 	    /*
 	     * Update CRC.  (Calculate adler32 again.)
 	     */
+#ifdef ENABLE_LIBDEFLATE
+	    out_zio.crc = libdeflate_adler32
+		((uint32_t)out_zio.crc, in_buffer + k * slice_size,
+		 (size_t)in_length);
+#else
 	    out_zio.crc = adler32((uLong)out_zio.crc,
 	        (Bytef *)(in_buffer + k * slice_size), (uInt)in_length);
+#endif
 
 	    /*
 	     * If this is last slice and its length is shorter than
@@ -472,9 +478,8 @@ ebzip_zip_file_internal(const char *out_file_name, const char *in_file_name,
 	 * Output status information unless `quiet' mode.
 	 */
 	if (!ebzip_quiet_flag
-	    || j >= progress_interval
-	    || ((i + k + 1) % progress_interval)
-	           > ((i + j) % progress_interval)) {
+	    && (j >= progress_interval
+		|| (i + j) / progress_interval > i / progress_interval)) {
 #if defined(PRINTF_LL_MODIFIER)
 	    fprintf(stderr, _("%4.1f%% done (%llu / %llu bytes)\n"),
 		    (double) (i + k + 1) * 100.0 / (double) total_slices,
